% reshape2Dwavelets.m - This file is part of the redWaveToolbox.
% This software aims at performing redundant wavelet transformations.
% Copyright 2014 CEA
% Contributor : Jeremy Rapin (jeremy.rapin@cea.fr)
% Created on 14/7/2014, last modified on 16/7/2014
% 
% This software is governed by the CeCILL license under French law and
% abiding by the rules of distribution of free software. You can use,
% modify and/ or redistribute the software under the terms of the CeCILL
% license as circulated by CEA, CNRS and INRIA at the following URL
% "http://www.cecill.info".
% 
% As a counterpart to the access to the source code and rights to copy,
% modify and redistribute granted by the license, users are provided only
% with a limited warranty and the software's author,  the holder of the
% economic rights,  and the successive licensors have only limited
% liability.
% 
% In this respect, the user's attention is drawn to the risks associated
% with loading,  using,  modifying and/or developing or reproducing the
% software by the user in light of its specific status of free software,
% that may mean that it is complicated to manipulate,  and that also
% therefore means that it is reserved for developers and experienced
% professionals having in-depth computer knowledge. Users are therefore
% encouraged to load and test the software's suitability as regards their
% requirements in conditions enabling the security of their systems and/or
% data to be ensured and,  more generally, to use and operate it in the
% same conditions as regards security.
% 
% The fact that you are presently reading this means that you have had
% knowledge of the CeCILL license and that you accept its terms.

% wy = reshape2Dwavelets(wx, parameters, rw2rice)
% reshapes the 2D wavelets from the redWave disposition to the Rice
% disposition, and conversely.
%
% Inputs:
% - wx: wavelet coefficients.
% - rw2rice: if >0 (default), from redWave to Rice, otherwise, from Rice to
% redWave.
% - parameters: parameters of the wavelet transform, with fields
% (required):
%   - L: number of scales of the wavelets
%   - dimensions: dimensions on which to compute the wavelets.
%
% CAUTION: not fully implemented, may not work if computing wavelets on the first dimension.


function wy = reshape2Dwavelets(wx, parameters, rw2rice)
if nargin < 3
    rw2rice = 1;
end
if ~isfield(parameters, 'L')
    error('The number of scales L is required');
end
L = parameters.L;
sizes = size(wx);
dims = parameters.dimensions;

if rw2rice > 0
    sizes(dims) = sizes(dims) / 2;
    sizes(dims(1)) = sizes(dims(1)) / L;
    sizes = [sizes, ones(1, 3 - length(sizes))];
    n1 = sizes(1); n2 = sizes(2); n3 = sizes(3);
    ind1 = 1 : n1; ind2 = 1 : n2;
    
    wy = zeros(n1, n2 * (3 * L + 1), n3);
    wy(ind1, ind2, :) = wx(ind1, ind2, :);
    for k = 1 : L
        wy(:, ind2 + n2 + (3 * (k - 1) + 0) * n2, :) =...
            wx(ind1 + 2 * (L - k) * n1 + n1, (1 : n2), :);
        wy(:, ind2 + n2 + (3 * (k - 1) + 1) * n2, :) =...
            wx(ind1 + 2 * (L - k) * n1, (1 : n2) + n2, :);
        wy(:, ind2 + n2 + (3 * (k - 1) + 2) * n2, :) =...
            wx(ind1 + 2 * (L - k) * n1+ n1, (1 : n2) + n2, :);
    end
else
    sizes(2) = sizes(2) / (3 * L + 1);
    n1 = sizes(1); n2 = sizes(2);
    ind1 = 1 : n1; ind2 = 1 : n2;
    
    outsize = sizes;
    outsize(dims) = 2 * outsize(dims);
    outsize(dims(1)) = outsize(dims(1)) * L;
    
    wy = zeros(outsize);
    wy(ind1, ind2, :) = wx(ind1, ind2, :);
    for k = 1 : L
        wy(ind1 + 2 * (L - k) * n1 + n1, (1 : n2), :) =...
            wx(:, ind2 + n2 + (3 * (k - 1) + 0) * n2, :);
        
        wy(ind1 + 2 * (L - k) * n1, (1 : n2) + n2, :) =...
            wx(:, ind2 + n2 + (3 * (k - 1) + 1) * n2, :);
        
        wy(ind1 + 2 * (L - k) * n1+ n1, (1 : n2) + n2, :) =...
            wx(:, ind2 + n2 + (3 * (k - 1) + 2) * n2, :);
    end
end
end



