% riceWave.m - This file is part of the redWaveToolbox.
% This software aims at performing redundant wavelet transformations.
% Copyright 2014 CEA
% Contributor : Jeremy Rapin (jeremy.rapin@cea.fr)
% Created on 14/7/2014, last modified on 16/7/2014
% 
% This software is governed by the CeCILL license under French law and
% abiding by the rules of distribution of free software. You can use,
% modify and/ or redistribute the software under the terms of the CeCILL
% license as circulated by CEA, CNRS and INRIA at the following URL
% "http://www.cecill.info".
% 
% As a counterpart to the access to the source code and rights to copy,
% modify and redistribute granted by the license, users are provided only
% with a limited warranty and the software's author,  the holder of the
% economic rights,  and the successive licensors have only limited
% liability.
% 
% In this respect, the user's attention is drawn to the risks associated
% with loading,  using,  modifying and/or developing or reproducing the
% software by the user in light of its specific status of free software,
% that may mean that it is complicated to manipulate,  and that also
% therefore means that it is reserved for developers and experienced
% professionals having in-depth computer knowledge. Users are therefore
% encouraged to load and test the software's suitability as regards their
% requirements in conditions enabling the security of their systems and/or
% data to be ensured and,  more generally, to use and operate it in the
% same conditions as regards security.
% 
% The fact that you are presently reading this means that you have had
% knowledge of the CeCILL license and that you accept its terms.

% y = riceWave(x, forward, options)
% warper for the rice wavelet toolbox, in order to be used exactly as the
% redWave toolbox.

function y = riceWave(x, forward, options)
[n1, n2, n3] = size(x);

if nargin < 2
    forward = 1;
end
if nargin < 3
    options = [];
end
if ~isfield(options, 'dimensions')
    options.dimensions = 2;
end
if ~isfield(options, 'qmf')
    options.qmf = [0.482962913145, 0.836516303738, 0.224143868042, -0.129409522551];
end
if ~isfield(options, 'L')
    options.L = 3;
end
if length(options.dimensions)  == 1
    if forward >= 0 %forward wavelets
        if options.dimensions == 1
            y = zeros(n1 * (options.L + 1), n2);
            for k = 1 : n2
                [yl, yh] = mrdwt(x(:, k), options.qmf, options.L);
                y(1 : n1, k) = yl;
                y(n1 + 1 : end, k) = yh(:);
            end
        else
            y = zeros(n1, n2 * (options.L + 1));
            for k = 1 : n1
                [yl, yh] = mrdwt(x(k, :)', options.qmf, options.L);
                y(k, 1 : n2) = yl;
                y(k, n2 + 1 : end) = yh(:)';
            end
        end
        
        
    else %backwards
        if options.dimensions == 1
            y = zeros(n1 / (options.L + 1), n2);
            for k = 1 : n2
                xl = x(1 : n1 / (options.L + 1), k);
                xh = reshape(x(n1 / (options.L + 1) + 1 : end, k), n1 / (options.L + 1), options.L);
                y(:, k) = mirdwt(xl, xh, options.qmf, options.L);
            end
        else
            y = zeros(n1, n2 / (options.L + 1));
            for k = 1 : n1
                xl = x(k, 1 : n2 / (options.L + 1))';
                xh = reshape(x(k, n2 / (options.L + 1) + 1 : end)', n2 / (options.L + 1), options.L);
                y(k, :)=mirdwt(xl, xh, options.qmf, options.L)';
            end
            
        end
        
    end
else
    if forward >= 0 %forward wavelets
        y = zeros(n1, n2 * (options.L * 3 + 1), n3);
        for k = 1 : n3
            [yl, yh] = mrdwt(x(:, :, k), options.qmf, options.L);
            y(:, 1 : n2, k) = yl;
            y(:, n2 + 1 : end, k) = yh;
        end

    else %backwards
            y = zeros(n1, n2 / (options.L * 3 + 1));
            sc = (options.L * 3 + 1);
            for k = 1 : n3
                xl = x(:, 1 : n2 / sc, k);
                xh = x(:, n2 / sc + 1 : end, k);
                y(:, :, k) = mirdwt(xl, xh, options.qmf, options.L);
            end
    end
    
end

end



