% normProjection.m - This file is part of nGMCALab.
% This software aims at performing non-negative matrix factorization.
% Copyright 2013 CEA
% Contributor : Jrmy Rapin (jeremy.rapin@cea.fr)
% Created on 20/08/13, last modified on 16/7/2014
% 
% This software is governed by the CeCILL  license under French law and
% abiding by the rules of distribution of free software.  You can  use, 
% modify and/ or redistribute the software under the terms of the CeCILL
% license as circulated by CEA, CNRS and INRIA at the following URL
% "http://www.cecill.info". 
% 
% As a counterpart to the access to the source code and  rights to copy,
% modify and redistribute granted by the license, users are provided only
% with a limited warranty  and the software's author,  the holder of the
% economic rights,  and the successive licensors  have only  limited
% liability. 
%
% In this respect, the user's attention is drawn to the risks associated
% with loading,  using,  modifying and/or developing or reproducing the
% software by the user in light of its specific status of free software,
% that may mean  that it is complicated to manipulate,  and  that  also
% therefore means  that it is reserved for developers  and  experienced
% professionals having in-depth computer knowledge. Users are therefore
% encouraged to load and test the software's suitability as regards their
% requirements in conditions enabling the security of their systems and/or 
% data to be ensured and,  more generally, to use and operate it in the 
% same conditions as regards security. 
% 
% The fact that you are presently reading this means that you have had
% knowledge of the CeCILL license and that you accept its terms.
%
%
%
% function X = normProjection(X,scales)
% Projection of X on the set of matrices with i-th column (resp. row) L2 norm
% inferior or equal to the i-th element of the row (resp. column) vector
% "scales".

function X = normProjection(X, scales)
[m, n] = size(X);
if size(scales, 1) == m
    n = dimNorm(X, 2);
    i = n > 0;
    X(i, :) = diag(min(n(i, :), scales(i, :)) ./ n(i, :)) * X(i, :);
    
else
    n = dimNorm(X, 1);
    i = n > 0;
    X(:, i) = X(:, i) * diag(min(n(:, i), scales(:, i)) ./ n(:, i));
end


end



